Class: Uchi::Field::Base::Index

Inherits:
Component
  • Object
show all
Defined in:
app/components/uchi/field/base.rb

Overview

Uchi::Field::Base::Index components render fields in the index view.

Instance Attribute Summary

Attributes inherited from Component

#field, #record, #repository

Class Method Summary collapse

Methods inherited from Component

#initialize, #value

Constructor Details

This class inherits a constructor from Uchi::Field::Base::Component

Class Method Details

.classes_for_table_cellObject

Returns the CSS classes to apply to the td or th of the table where this field is rendered.



43
44
45
# File 'app/components/uchi/field/base.rb', line 43

def classes_for_table_cell
  []
end