Class: Uchi::Field::Id

Inherits:
Number
  • Object
show all
Defined in:
app/components/uchi/field/id.rb

Overview

The Id field is intended for unique identifiers, such as primary keys. It contains a link to the records show page, and is not considered editable. As such it is only displayed in index and show views by default.

Defined Under Namespace

Classes: Index, Show