Class: Uchi::Ui::Navigation

Inherits:
ViewComponent::Base
  • Object
show all
Defined in:
app/components/uchi/ui/navigation.rb

Overview

Renders the main navigation menu visible at the side of the viewport.

The template for this component has access to the following methods:

  • items: Returns an Array of Hashes containing :label and :path keys for each item to render in the navigation.
  • navigatable_repositories: Returns an Array of Uchi::Repository instances. The Array is sorted alphanumerically by the navigation_label for each repository.
  • repositories: Returns an Array with an instance of each Uchi::Repository in the application.