Class: Uchi::Field::Base::Index
- Defined in:
- app/components/uchi/field/base.rb
Overview
Uchi::Field::Base::Index components render fields in the index view.
Direct Known Subclasses
Uchi::Field::BelongsTo::Index, Uchi::Field::Blank::Index, Uchi::Field::Boolean::Index, Date::Index, DateTime::Index, File::Index, HasAndBelongsToMany::Index, HasMany::Index, Id::Index, Image::Index, Number::Index, Select::Index, String::Index, Text::Index
Instance Attribute Summary
Attributes inherited from Component
Class Method Summary collapse
-
.classes_for_table_cell ⇒ Object
Returns the CSS classes to apply to the td or th of the table where this field is rendered.
Methods inherited from Component
Constructor Details
This class inherits a constructor from Uchi::Field::Base::Component
Class Method Details
.classes_for_table_cell ⇒ Object
Returns the CSS classes to apply to the td or th of the table where this field is rendered.
43 44 45 |
# File 'app/components/uchi/field/base.rb', line 43 def classes_for_table_cell [] end |