Class: Uchi::Ui::Navigation
- Inherits:
-
ViewComponent::Base
- Object
- ViewComponent::Base
- Uchi::Ui::Navigation
- Defined in:
- app/components/uchi/ui/navigation.rb
Overview
Renders the main navigation menu visible at the side of the viewport.
The template for this component has access to the following methods:
items: Returns anArrayofHashescontaining :label and :path keys for each item to render in the navigation.navigatable_repositories: Returns anArrayofUchi::Repositoryinstances. TheArrayis sorted alphanumerically by thenavigation_labelfor each repository.repositories: Returns anArraywith an instance of eachUchi::Repositoryin the application.